@@ -12,12 +12,15 @@ from onnx2tf.utils.common_functions import (
     print_node_info,
     inverted_operation_enable_disable,
     make_tf_node_info,
+    get_replacement_parameter,
+    pre_process_transpose,
+    post_process_transpose,
 )
-from onnx2tf.utils.enums import ONNX_DTYPES_TO_TF_DTYPES
 
 
 @print_node_info
 @inverted_operation_enable_disable
+@get_replacement_parameter
 def make_node(
     *,
     graph_node: gs.Node,
@@ -55,8 +58,6 @@ def make_node(
         kwargs['replace_argmax_to_fused_argmax_and_indicies_is_int64']
     replace_argmax_to_fused_argmax_and_indicies_is_float32 = \
         kwargs['replace_argmax_to_fused_argmax_and_indicies_is_float32']
-    fused_argmax_scale_ratio = \
-        kwargs['fused_argmax_scale_ratio']
 
     axis = graph_node.attrs.get('axis', 0)
     # NCHW->NHWC, NCDHW->NDHWC
@@ -82,6 +83,15 @@ def make_node(
     # Generation of TF OP
     input_tensor = tf_layers_dict[graph_node_input.name]['tf_node'] \
         if isinstance(graph_node_input, gs.Variable) else graph_node_input
+
+    # Pre-process transpose
+    input_tensor = pre_process_transpose(
+        value_before_transpose=input_tensor,
+        param_target='inputs',
+        param_name=graph_node.inputs[0].name,
+        **kwargs,
+    )
+
     ### 1. Select last index or first index
     reversed_tensor = None
     if not select_last_index:
@@ -140,7 +150,6 @@ def make_node(
             keepdims=keepdims,
             replace_argmax_to_fused_argmax_and_indicies_is_int64=replace_argmax_to_fused_argmax_and_indicies_is_int64,
             replace_argmax_to_fused_argmax_and_indicies_is_float32=replace_argmax_to_fused_argmax_and_indicies_is_float32,
-            fused_argmax_scale_ratio=fused_argmax_scale_ratio,
         )
         tf_op_type = 'alternative_fused_argmax'
     else:
@@ -163,6 +172,14 @@ def make_node(
 
     tf_layers_dict[graph_node_output.name]['tf_node'] = final_tensor
 
+    # Post-process transpose
+    tf_layers_dict[graph_node_output.name]['tf_node'] = post_process_transpose(
+        value_before_transpose=tf_layers_dict[graph_node_output.name]['tf_node'],
+        param_target='outputs',
+        param_name=graph_node.outputs[0].name,
+        **kwargs,
+    )
+
     # Generation of Debug Info
     tf_layers_dict[graph_node_output.name]['tf_node_info'] = \
         make_tf_node_info(
