@@ -65,12 +65,18 @@ def make_node(
         if isinstance(graph_node_input, gs.Variable) else graph_node_input
 
     # Pre-process transpose
+    before_trans_shape = input_tensor.shape
     input_tensor = pre_process_transpose(
         value_before_transpose=input_tensor,
         param_target='inputs',
         param_name=graph_node.inputs[0].name,
         **kwargs,
     )
+    after_trans_shape = input_tensor.shape
+    if 'nhwc' in tf_layers_dict[graph_node_output.name].keys() \
+        and tf_layers_dict[graph_node_output.name]['nhwc'] == True \
+        and before_trans_shape != after_trans_shape:
+        tf_layers_dict[graph_node_output.name].pop('nhwc')
 
     tf_op_type = None
     if not replace_asin_to_pseudo_asin:
@@ -88,12 +94,18 @@ def make_node(
         tf_op_type = 'alternative_asin'
 
     # Post-process transpose
+    before_trans_shape = tf_layers_dict[graph_node_output.name]['tf_node'].shape
     tf_layers_dict[graph_node_output.name]['tf_node'] = post_process_transpose(
         value_before_transpose=tf_layers_dict[graph_node_output.name]['tf_node'],
         param_target='outputs',
         param_name=graph_node.outputs[0].name,
         **kwargs,
     )
+    after_trans_shape = tf_layers_dict[graph_node_output.name]['tf_node'].shape
+    if 'nhwc' in tf_layers_dict[graph_node_output.name].keys() \
+        and tf_layers_dict[graph_node_output.name]['nhwc'] == True \
+        and before_trans_shape != after_trans_shape:
+        tf_layers_dict[graph_node_output.name].pop('nhwc')
 
     # Generation of Debug Info
     tf_layers_dict[graph_node_output.name]['tf_node_info'] = \
