@@ -10,12 +10,16 @@ from onnx2tf.utils.common_functions import (
     print_node_info,
     inverted_operation_enable_disable,
     make_tf_node_info,
+    get_replacement_parameter,
+    pre_process_transpose,
+    post_process_transpose,
 )
 from onnx2tf.utils.colors import Color
 
 
 @print_node_info
 @inverted_operation_enable_disable
+@get_replacement_parameter
 def make_node(
     *,
     graph_node: gs.Node,
@@ -64,6 +68,20 @@ def make_node(
     grid = tf_layers_dict[graph_node_input_2.name]['tf_node'] \
         if isinstance(graph_node_input_2, gs.Variable) else graph_node_input_2
 
+    # Pre-process transpose
+    image = pre_process_transpose(
+        value_before_transpose=image,
+        param_target='inputs',
+        param_name=graph_node.inputs[0].name,
+        **kwargs,
+    )
+    grid = pre_process_transpose(
+        value_before_transpose=grid,
+        param_target='inputs',
+        param_name=graph_node.inputs[1].name,
+        **kwargs,
+    )
+
     align_corners = bool(graph_node.attrs.get('align_corners', 0))
     mode = graph_node.attrs.get('mode', 'bilinear')
     padding_mode = graph_node.attrs.get('padding_mode', 'zeros')
@@ -300,6 +318,14 @@ def make_node(
     tf_layers_dict[graph_node_output.name]['tf_node'] = \
         output_tensor = output_tensor * mask
 
+    # Post-process transpose
+    tf_layers_dict[graph_node_output.name]['tf_node'] = post_process_transpose(
+        value_before_transpose=tf_layers_dict[graph_node_output.name]['tf_node'],
+        param_target='outputs',
+        param_name=graph_node.outputs[0].name,
+        **kwargs,
+    )
+
     # Generation of Debug Info
     tf_layers_dict[graph_node_output.name]['tf_node_info'] = \
         make_tf_node_info(
