@@ -9,12 +9,19 @@ from onnx2tf.utils.common_functions import (
     print_node_info,
     inverted_operation_enable_disable,
     make_tf_node_info,
+    disable_unnecessary_transpose,
     shape_unmatched_special_avoidance_workaround,
+    pre_explicit_broadcast,
+    explicit_broadcast,
+    get_replacement_parameter,
+    pre_process_transpose,
+    post_process_transpose,
 )
 
 
 @print_node_info
 @inverted_operation_enable_disable
+@get_replacement_parameter
 def make_node(
     *,
     graph_node: gs.Node,
@@ -64,6 +71,31 @@ def make_node(
     input_tensor_2 = tf_layers_dict[graph_node_input_2.name]['tf_node'] \
         if isinstance(graph_node_input_2, gs.Variable) else graph_node_input_2
 
+    # Disable unnecessary Transpose
+    #   1. If both x and y are gs.Variable
+    #   2. If only one of the two is the output of Transpose
+    #   3. If the perm of the Transpose is [0,2,1] or [0,3,1,2] or [0,4,1,2,3]
+    #   4. Furthermore, if the shape of x and y are mismatched
+    graph_node_input_1, graph_node_input_2, input_tensor_1, input_tensor_2 = \
+        disable_unnecessary_transpose(
+            graph_node_input_1=graph_node_input_1,
+            graph_node_input_2=graph_node_input_2,
+            input_tensor_1=input_tensor_1,
+            input_tensor_2=input_tensor_2,
+        )
+
+    input_tensor_1, input_tensor_2 = pre_explicit_broadcast(
+        input_tensor_1=input_tensor_1,
+        input_tensor_2=input_tensor_2,
+    )
+
+    input_tensor_1, input_tensor_2 = explicit_broadcast(
+        const_or_var_1=input_tensor_1,
+        const_or_var_2=input_tensor_2,
+        graph_node=graph_node,
+        tf_layers_dict= tf_layers_dict,
+    )
+
     # Shape Unmatched Special Avoidance Workaround
     # At least one True value for same_input_shape_as_onnx
     # At least one True value in nhwc_flags
@@ -76,6 +108,20 @@ def make_node(
         tf_layers_dict=tf_layers_dict,
     )
 
+    # Pre-process transpose
+    input_tensor_1 = pre_process_transpose(
+        value_before_transpose=input_tensor_1,
+        param_target='inputs',
+        param_name=graph_node.inputs[0].name,
+        **kwargs,
+    )
+    input_tensor_2 = pre_process_transpose(
+        value_before_transpose=input_tensor_2,
+        param_target='inputs',
+        param_name=graph_node.inputs[1].name,
+        **kwargs,
+    )
+
     tf_layers_dict[graph_node_output.name]['tf_node'] = \
         tf.math.mod(
             x=input_tensor_1,
@@ -83,6 +129,14 @@ def make_node(
             name=graph_node.name,
         )
 
+    # Post-process transpose
+    tf_layers_dict[graph_node_output.name]['tf_node'] = post_process_transpose(
+        value_before_transpose=tf_layers_dict[graph_node_output.name]['tf_node'],
+        param_target='outputs',
+        param_name=graph_node.outputs[0].name,
+        **kwargs,
+    )
+
     # Generation of Debug Info
     tf_layers_dict[graph_node_output.name]['tf_node_info'] = \
         make_tf_node_info(
